@@ -75,6 +75,7 @@ def send_metadata_to_redshift(table_name: str, database: Optional[str] = None, f
                             f"Table Schema: {table['details']['table_schema']}\n\n" \
                             f"Description: {table['details']['description']}\n\n" \
                             f"Source Name: {table['details']['source_name']}\n\n" \
+                            f"Source UUID: {table['details']['source_uuid']}\n\n" \
                             f"Geographical Coverage: {table['details']['geographical_coverage']}\n\n" \
                             f"Geographical Granularity: {table['details']['geographical_granularity']}\n\n" \
                             f"Update Frequency: {table['details']['update_frequency']}\n\n" \
@@ -621,7 +622,8 @@ class RedshiftOperator:
         :param verbose: Details of the Redshift Operator call on the tables.
         :return:
         """
-        self.get_DDL(verbose=verbose)
+        if self.ddl_table is None:
+            self.get_DDL(verbose=verbose)
 
         df_filtered = self.ddl_table[self.ddl_table.create_query.str.contains(f'[\s,"]{col_name}[\s"]')]
 
